@@ -147,13 +147,13 @@ class WatchMixin(MixinProtocol):
         related_browse_id = get_tab_browse_id(watchNextRenderer, 2)
 
         results = nav(
-            watchNextRenderer, TAB_CONTENT + ["musicQueueRenderer", "content", "playlistPanelRenderer"]
+            watchNextRenderer, [*TAB_CONTENT, "musicQueueRenderer", "content", "playlistPanelRenderer"]
         )
         playlist = next(
             filter(
                 bool,
                 map(
-                    lambda x: nav(x, ["playlistPanelVideoRenderer"] + NAVIGATION_PLAYLIST_ID, True),
+                    lambda x: nav(x, ["playlistPanelVideoRenderer", *NAVIGATION_PLAYLIST_ID], True),
                     results["contents"],
                 ),
             ),
